@@ -196,15 +196,15 @@ class WheelBuilder:
             self._add_file(full_path, dir_in_whl + rel_path)
         for name in {"lib", "share"}:
             for full_path in common.walk_data_dir(str(Path(self.output) / name)):
-                rel_path = os.path.relpath(full_path, self.data_directory).partition(name + "/")[2]
-                self._add_file(full_path, dir_in_whl + name + "/" + rel_path)
+                rel_path = os.path.relpath(full_path, self.data_directory).partition(name + os.path.sep)[2]
+                self._add_file(full_path, dir_in_whl + name + os.path.sep + rel_path)
 
     def add_scripts_directory(self):
         dir_in_whl = '{}.data/scripts/'.format(
             common.normalize_dist_name(self.metadata.name, self.metadata.version)
         )
         for full_path in common.walk_data_dir(str(Path(self.output) / "bin")):
-            rel_path = os.path.relpath(full_path, self.data_directory).partition("bin/")[2]
+            rel_path = os.path.relpath(full_path, self.data_directory).partition("bin" + os.path.sep)[2]
             self._add_file(full_path, dir_in_whl + rel_path)
 
     def add_headers_directory(self):
@@ -212,7 +212,7 @@ class WheelBuilder:
             common.normalize_dist_name(self.metadata.name, self.metadata.version)
         )
         for full_path in common.walk_data_dir(str(Path(self.output) / "include")):
-            rel_path = os.path.relpath(full_path, self.data_directory).partition("include/")[2]
+            rel_path = os.path.relpath(full_path, self.data_directory).partition("include" + os.path.sep)[2]
             self._add_file(full_path, dir_in_whl + rel_path)
 
     def write_metadata(self):
